@@ -6,7 +6,7 @@ from django.contrib.admin.widgets import AdminFileWidget
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
 from django.utils.encoding import force_text
-from .forms import ViddlerUploadForm
+from .forms import ViddlerUploadForm, ViddlerChangeForm
 from .settings import get_viddler
 
 
@@ -32,15 +32,18 @@ class ViddlerAdmin(admin.ModelAdmin):
     add_form_template = "admin/viddler/viddlervideo/add_form.html"
 
     add_form = ViddlerUploadForm
-
-    readonly_fields = ('viddler_id', 'last_synced', 'status', 'author', 'length',
-        'url', 'thumbnail_url', 'html5_video_source', 'audio_only', 'view_count',
-        'impression_count', 'upload_time', 'made_public_time', 'favorite',
-        'comment_count', 'thumbnails_count', 'thumbnail_index', 'files')
+    form = ViddlerChangeForm
+    readonly_fields = (
+        'viddler_id', 'last_synced', 'status', 'author', 'length',
+        'url', 'thumbnail_url', 'html5_video_source', 'audio_only',
+        'view_count', 'impression_count', 'upload_time', 'made_public_time',
+        'favorite', 'comment_count', 'thumbnails_count', 'thumbnail_index',
+        'files', 'embed_code')
 
     add_fieldsets = (
         (None, ({
-            'fields': ('uploadtoken', 'callback', 'title', 'description', 'slug', 'file')
+            'fields': ('uploadtoken', 'callback', 'title', 'description',
+                       'slug', 'file')
         })),
     )
 
@@ -49,18 +52,24 @@ class ViddlerAdmin(admin.ModelAdmin):
             'fields': ('viddler_id', 'status', 'author', 'last_synced')
         }),
         ('Details', {
-            'fields': ('title', 'description', 'tags', 'permalink',
-                'age_limit', 'length', 'url', 'html5_video_source',
-                'thumbnail_url', ),
+            'fields': (
+                'title', 'description', 'tags', 'permalink', 'age_limit',
+                'length', 'url', 'embed_code', 'html5_video_source',
+                'thumbnail_url',
+            ),
         }),
         ('Interaction', {
-            'fields': ('view_permission', 'embed_permission',
+            'fields': (
+                'view_permission', 'embed_permission',
                 'tagging_permission', 'commenting_permission',
-                'download_permission', ),
+                'download_permission',
+            ),
         }),
         ('Counts', {
-            'fields': ('view_count', 'impression_count', 'favorite',
-            'comment_count', 'upload_time', 'made_public_time', ),
+            'fields': (
+                'view_count', 'impression_count', 'favorite', 'comment_count',
+                'upload_time', 'made_public_time',
+            ),
         }),
     )
     prepopulated_fields = {"slug": ("title",)}
@@ -71,6 +80,10 @@ class ViddlerAdmin(admin.ModelAdmin):
     search_fields = ['title', 'slug', 'description', 'author', ]
     list_per_page = 100
 
+    def embed_code(self, obj):
+        return obj.get_embed_code()
+    embed_code.short_description = "embed code"
+
     def html_title(self, obj):
         return obj.title
     html_title.allow_tags = True
