@@ -17,3 +17,10 @@ class ViddlerUploadForm(forms.ModelForm):
         exclude = ('age_limit', 'permalink', 'tags', 'view_permission',
             'embed_permission', 'tagging_permission', 'commenting_permission',
             'download_permission')
+
+
+class ViddlerChangeForm(forms.ModelForm):
+    embed_code = forms.CharField(required=False)
+
+    class Meta:
+        model = ViddlerVideo
